<?php

namespace App;

use Exception;
use GuzzleHttp\Client;

class Request
{
    private Client $client;
    private array $query;
    private Logger $logger;
    private Config $config;

    public function __construct(Logger $logger, string $hostname)
    {
        $this->logger = $logger;

        $this->config = new Config();

        $this->client = new Client(
            [
                'base_uri' => $this->config->get('url')
            ]
        );

        $this->query = [
            'warehouseId' => $this->config->get('warehouseId'),
            'hostname' => $hostname
        ];
    }

    public function getLabelTask(): array
    {
        try {
            $response = $this->client->post(
                'api/labels/task/get-pack',
                [
                    'query' => $this->query,
                    'headers' => [
                        'Authorization' => $this->config->get('token'),
                    ]
                ]
            );

            $content = $response->getBody()->getContents();

            $content = json_decode($content, true, 512, JSON_THROW_ON_ERROR);

            if (array_key_exists('error', $content)) {
                $this->sendMessage($content['error']);
            }

            if (!array_key_exists('tasks', $content)) {
                $this->sendMessage('Отсутствует ключ tasks в ответе api/labels/task/get-pack');
            }

            return $content['tasks'];
        } catch (Exception $exception) {
            $this->sendMessage($exception->getFile() . ' ' . $exception->getLine() . ' ' . $exception->getMessage());
        }

        return [];
    }

    public function sendMessage(string $message, int $taskId = null): void
    {
        $this->logger->writeLog($message);

        try {
            $this->client->post(
                'api/labels/log',
                [
                    'form_params' => [
                        'warehouseId' => $this->query['warehouseId'],
                        'message' => $message,
                        'taskId' => $taskId
                    ]
                ]
            );
        } catch (Exception $exception) {
            $this->logger->writeLog(
                $exception->getFile() . ' ' . $exception->getLine() . ' ' . $exception->getMessage()
            );
        }
    }
}